This is a theme based on Bootstrap 4 and the [blog example](https://getbootstrap.com/docs/4.0/examples/blog/) by @mdo.

Note that unlike previous versions of Bootstrap, icon fonts are not built-in.
You can use Font Awesome for this.

This theme **does not** support Bootswatch font/color schemes.
